#INKSCAPE=inkscape
INKSCAPE=/Applications/Inkscape.app/Contents/Resources/bin/inkscape
rm *.png
for i in *.svg; do $INKSCAPE $i --export-png=`echo $i | sed -e 's/svg$/png/'`; done
